# 
# used like this:
#
# ldap_uri = 'ldap://ldap-server'
# ldap_base = 'dc=example,dc=com'
# ldap_ssl  = 'true'
# if ssl is not activated just don't put the line above.
# include openldap::client

class openldap::client {
    package { [
        "base-files",
        "libnss-ldap",
        "libpam-ldap",
        "libpam-cracklib",
        "nscd"
        ]: ensure => installed
    }
    
    case $operatingsystem {
        Debian: {
            file {
                "/etc/pam_ldap.conf":
                    require => Package["base-files"],
                    ensure => present,
                    content => template("openldap/pam_ldap.conf.erb");
                "/etc/libnss-ldap.conf":
                    require => Package["base-files"],
                    ensure => present,
                    content => template("openldap/ldap.conf.erb");
                }
        }
        Ubuntu: {
            file {
                "/etc/ldap.conf":
                    require => Package["base-files"],
                    ensure => present,
                    content => template("openldap/ldap.conf.erb");
                "/etc/ldap/ldap.conf":
                    require => Package["base-files"],
                    ensure => present,
                    content => template("openldap/ldap.conf.erb");
                }
        }
        default: {
           err("Your $operatingsystem is not supported yet to configure openldap-client")
        }
    }

    file { 
        "/etc/nsswitch.conf":
            source => "puppet:///openldap/etc/nsswitch.conf",
            ensure => present,
            require => Package["base-files"];
        "/etc/pam.d":
            ensure  => directory,
            mode    => 644,
            owner   => root,
            group   => root,
            source  => "puppet:///openldap/etc/pam.d/",
            recurse => "true",
            require => Package[base-files];
    }
}
